/* Copyright 2012  Jesper K. Pedersen <blackie@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef VIDEOLENGTHEXTRACTOR_H
#define VIDEOLENGTHEXTRACTOR_H

#include <DB/FileName.h>

#include <QObject>

namespace Utilities
{
class Process;
}

namespace ImageManager
{

/**
  \brief \todo
  \see \ref videothumbnails
*/
class VideoLengthExtractor : public QObject
{
    Q_OBJECT
public:
    explicit VideoLengthExtractor(QObject *parent = nullptr);
    void extract(const DB::FileName &fileName);

signals:
    void lengthFound(int length);
    void unableToDetermineLength();

private slots:
    void processEnded();

private:
    Utilities::Process *m_process;
    DB::FileName m_fileName;
};

}

#endif // VIDEOLENGTHEXTRACTOR_H
// vi:expandtab:tabstop=4 shiftwidth=4:
